# Exact hypervolume calculation for 2D and 3D objective 

This folder contains two mex files to calculate the hypervolume for the 2D 
and 3D case in asymptotically optimal time. 

The algorithm was created by the "Multicriteria Optimizaiton and Decision Analysis (MODA)
Research group at LIACS, Leiden University.

Group website: http://liacs.leidenuniv.nl/~csmoda/index.php?page=code

Implementation: Kaifeng Yang, Michael T. M. Emmerich

Algorithm: Kaifeng Yang and Michael T. M. Emmerich, LIACS, Leiden University

For the 2D case the mex-file used follows the description of:
Yang, K., Emmerich, M., Deutz, A., & Fonseca, C. M. (2017, March). Computing 3-D Expected Hypervolume Improvement 
and Related Integrals in Asymptotically Optimal Time. In International  
Conference on Evolutionary Multi-Criterion Optimization (pp. 685-700). Springer, Cham.

For the 3D case the mex-file used follows the description of:
Emmerich, M., Yang, K., Deutz, A., Wang, H., & Fonseca, C. M. (2016). 
A multicriteria generalization of bayesian global optimization. 
In Advances in Stochastic and Deterministic Global Optimization (pp. 229-242). Springer International Publishing.

For the original unmodified mex files refer to http://liacs.leidenuniv.nl/~csmoda/index.php?page=code.
